import 'styled-components';
import {
  ColorsInterface,
  FontFamilyInterface,
  FontSizeInterface,
  LineHengthInterface,
  FontWeightInterface,
  RadiusInterface
} from '../tokens'

interface TypographyInterface {
  fontSize: keyof FontSizeInterface
  lineHeight: keyof LineHengthInterface
  letterSpacing?: number
  fontWeight: keyof FontWeightInterface
}

type SpaThemeTypes = {
  name: string
  fonts: {
    default: keyof FontFamilyInterface
    headings: keyof FontFamilyInterface
  }
  colors: Record<string, keyof ColorsInterface>
  typography: {
    [key: string]: TypographyInterface
  }
  borderRadius?: keyof RadiusInterface
  awesomegrid?: {
    mediaQuery: string
    columns: Record<string, number>
    gutterWidth: Record<string, number>
    paddingWidth: Record<string, number>
    container: Record<string, string>
    breakpoints: Record<string, number>
  }
}

declare module 'styled-components' {
  export interface DefaultTheme extends SpaThemeTypes {}
}

const spaTheme: SpaThemeTypes = {
  name: 'spa-liguelead',
  fonts: {
    default: 'manrope',
    headings: 'manrope'
  },
  colors: {
    ghost: 'transparent',
    white: 'white',
    black: 'black',
    primary: 'plankton800',
    primaryDark: 'plankton1000',
    primaryDarker: 'plankton1100',
    primaryLight: 'plankton200',
    primaryLighter: 'plankton50',
    secondary: 'thanos800',
    secondaryDark: 'thanos900',
    secondaryDarker: 'thanos1100',
    secondaryLight: 'thanos200',
    secondaryLighter: 'thanos50',
    bgWhite: 'neutral50',
    bgSoft: 'neutral100',
    danger50: 'red50',
    danger100: 'red100',
    danger200: 'red200',
    danger300: 'red300',
    warning50: 'yellow50',
    warning100: 'yellow100',
    warning200: 'yellow200',
    warning300: 'yellow300',
    success50: 'green50',
    success100: 'green100',
    success200: 'green200',
    success300: 'green300',
    info50: 'blue50',
    info100: 'blue100',
    info200: 'blue200',
    info300: 'blue300',
    neutral50: 'neutral50',
    neutral100: 'neutral100',
    neutral200: 'neutral200',
    neutral300: 'neutral300',
    neutral400: 'neutral400',
    neutral500: 'neutral500',
    neutral600: 'neutral600',
    neutral700: 'neutral700',
    neutral800: 'neutral800',
    neutral900: 'neutral900',
    neutral1000: 'neutral1000',
    neutral1100: 'neutral1100'
  },
  typography: {
    body01: {
      fontSize: 'fontSize14',
      lineHeight: 'lineHeight22',
      letterSpacing: 0,
      fontWeight: 'fontWeight400'
    },
    body02: {
      fontSize: 'fontSize16',
      lineHeight: 'lineHeight24',
      letterSpacing: 0,
      fontWeight: 'fontWeight400'
    },
    heading01: {
      fontSize: 'fontSize18',
      lineHeight: 'lineHeight26',
      letterSpacing: 0,
      fontWeight: 'fontWeight500'
    },
    hading02: {
      fontSize: 'fontSize20',
      lineHeight: 'lineHeight28',
      letterSpacing: 0,
      fontWeight: 'fontWeight600'
    },
    hading03: {
      fontSize: 'fontSize24',
      lineHeight: 'lineHeight32',
      letterSpacing: 0,
      fontWeight: 'fontWeight600'
    },
    hading04: {
      fontSize: 'fontSize32',
      lineHeight: 'lineHeight40',
      letterSpacing: 0,
      fontWeight: 'fontWeight600'
    }
  },
  borderRadius: 'radius4',
  awesomegrid: {
    mediaQuery: 'only screen',
    columns: {
      xs: 12,
      sm: 12,
      md: 12,
      lg: 12,
      xl: 12
    },
    gutterWidth: {
      xs: 2,
      sm: 2,
      md: 2,
      lg: 2,
      xl: 2
    },
    paddingWidth: {
      xs: 2,
      sm: 1,
      md: 1,
      lg: 1,
      xl: 1
    },
    container: {
      xs: 'full',
      sm: 'full',
      md: 'full',
      lg: 'full'
    },
    breakpoints: {
      xs: 1,
      sm: 48,
      md: 62,
      lg: 75
    }
  }
}

export default spaTheme
